@@ -28,6 +28,6 @@ extern enum bitset_type bitset_stats_type_get PARAMS ((bitset));
 extern size_t bitset_stats_bytes PARAMS ((void));
 
 extern bitset bitset_stats_init PARAMS ((bitset, bitset_bindex, 
-					 enum bitset_type));
+					 enum_bitset_type));
 
 #endif
