@@ -1,5 +1,5 @@
 /* Generate the nondeterministic finite state machine for bison,
-   Copyright 1984, 1986, 1989, 2000 Free Software Foundation, Inc.
+   Copyright 1984, 1986, 1989, 2000, 2001, 2002  Free Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
@@ -25,10 +25,4 @@
 
 void generate_states PARAMS ((void));
 
-extern int nstates;
-extern int final_state;
-extern core *first_state;
-extern shifts *first_shift;
-extern reductions *first_reduction;
-
 #endif /* !LR0_H_ */
